summaryrefslogtreecommitdiffstats
path: root/k9author/menuEdit.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
commitb0e912c8b3d02a518fedda28c3180eb4794a7520 (patch)
tree07d344862562fab58cbe2df39d13d16f2e4d2bea /k9author/menuEdit.cpp
parent4d695ec81fe4d4335ee82c7a9346ad9c9e144ecc (diff)
downloadk9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.tar.gz
k9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.zip
TQt4 convert k9copy
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/k9copy@1233843 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'k9author/menuEdit.cpp')
-rw-r--r--k9author/menuEdit.cpp110
1 files changed, 55 insertions, 55 deletions
diff --git a/k9author/menuEdit.cpp b/k9author/menuEdit.cpp
index db313d2..d9a74c4 100644
--- a/k9author/menuEdit.cpp
+++ b/k9author/menuEdit.cpp
@@ -9,40 +9,40 @@
#include "menuEdit.h"
-#include <qvariant.h>
-#include <qlabel.h>
+#include <tqvariant.h>
+#include <tqlabel.h>
#include <kurlrequester.h>
#include <kcolorbutton.h>
#include <kpushbutton.h>
-#include <qcombobox.h>
-#include <qlineedit.h>
-#include <qframe.h>
-#include <qlayout.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
+#include <tqcombobox.h>
+#include <tqlineedit.h>
+#include <tqframe.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
#include "kurlrequester.h"
#include "klineedit.h"
#include "kpushbutton.h"
#include "kcolorbutton.h"
/*
* Constructs a menuEdit as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/
-menuEdit::menuEdit( QWidget* parent, const char* name, WFlags fl )
- : QWidget( parent, name, fl )
+menuEdit::menuEdit( TQWidget* tqparent, const char* name, WFlags fl )
+ : TQWidget( tqparent, name, fl )
{
if ( !name )
setName( "menuEdit" );
- menuEditLayout = new QGridLayout( this, 1, 1, 2, 6, "menuEditLayout");
+ menuEditLayout = new TQGridLayout( this, 1, 1, 2, 6, "menuEditLayout");
- textLabel2 = new QLabel( this, "textLabel2" );
- textLabel2->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)5, 0, 0, textLabel2->sizePolicy().hasHeightForWidth() ) );
+ textLabel2 = new TQLabel( this, "textLabel2" );
+ textLabel2->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)5, 0, 0, textLabel2->sizePolicy().hasHeightForWidth() ) );
menuEditLayout->addMultiCellWidget( textLabel2, 5, 6, 0, 0 );
- textLabel1 = new QLabel( this, "textLabel1" );
- textLabel1->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)5, 0, 0, textLabel1->sizePolicy().hasHeightForWidth() ) );
+ textLabel1 = new TQLabel( this, "textLabel1" );
+ textLabel1->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)5, 0, 0, textLabel1->sizePolicy().hasHeightForWidth() ) );
menuEditLayout->addWidget( textLabel1, 4, 0 );
@@ -51,76 +51,76 @@ menuEdit::menuEdit( QWidget* parent, const char* name, WFlags fl )
menuEditLayout->addMultiCellWidget( urBackground, 4, 4, 1, 5 );
cbColor = new KColorButton( this, "cbColor" );
- cbColor->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, cbColor->sizePolicy().hasHeightForWidth() ) );
+ cbColor->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)0, 0, 0, cbColor->sizePolicy().hasHeightForWidth() ) );
menuEditLayout->addWidget( cbColor, 6, 1 );
bFont = new KPushButton( this, "bFont" );
- bFont->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, bFont->sizePolicy().hasHeightForWidth() ) );
+ bFont->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)0, 0, 0, bFont->sizePolicy().hasHeightForWidth() ) );
menuEditLayout->addWidget( bFont, 6, 2 );
- cbPosTitle = new QComboBox( FALSE, this, "cbPosTitle" );
- cbPosTitle->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, cbPosTitle->sizePolicy().hasHeightForWidth() ) );
+ cbPosTitle = new TQComboBox( FALSE, this, "cbPosTitle" );
+ cbPosTitle->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)0, 0, 0, cbPosTitle->sizePolicy().hasHeightForWidth() ) );
menuEditLayout->addWidget( cbPosTitle, 6, 3 );
- spacer1 = new QSpacerItem( 51, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
+ spacer1 = new TQSpacerItem( 51, 20, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
menuEditLayout->addMultiCell( spacer1, 6, 6, 4, 5 );
- leTitle = new QLineEdit( this, "leTitle" );
+ leTitle = new TQLineEdit( this, "leTitle" );
menuEditLayout->addMultiCellWidget( leTitle, 5, 5, 1, 4 );
bAddText = new KPushButton( this, "bAddText" );
- bAddText->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)4, (QSizePolicy::SizeType)4, 0, 0, bAddText->sizePolicy().hasHeightForWidth() ) );
- bAddText->setMinimumSize( QSize( 24, 24 ) );
- bAddText->setMaximumSize( QSize( 24, 24 ) );
+ bAddText->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)4, (TQSizePolicy::SizeType)4, 0, 0, bAddText->sizePolicy().hasHeightForWidth() ) );
+ bAddText->setMinimumSize( TQSize( 24, 24 ) );
+ bAddText->setMaximumSize( TQSize( 24, 24 ) );
menuEditLayout->addWidget( bAddText, 5, 5 );
- lTitle = new QLabel( this, "lTitle" );
- lTitle->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, 0, 0, lTitle->sizePolicy().hasHeightForWidth() ) );
- QFont lTitle_font( lTitle->font() );
+ lTitle = new TQLabel( this, "lTitle" );
+ lTitle->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)0, 0, 0, lTitle->sizePolicy().hasHeightForWidth() ) );
+ TQFont lTitle_font( lTitle->font() );
lTitle_font.setBold( TRUE );
lTitle->setFont( lTitle_font );
menuEditLayout->addMultiCellWidget( lTitle, 0, 0, 0, 5 );
- textLabel1_2 = new QLabel( this, "textLabel1_2" );
+ textLabel1_2 = new TQLabel( this, "textLabel1_2" );
menuEditLayout->addWidget( textLabel1_2, 2, 0 );
- cbStart = new QComboBox( FALSE, this, "cbStart" );
+ cbStart = new TQComboBox( FALSE, this, "cbStart" );
menuEditLayout->addMultiCellWidget( cbStart, 2, 2, 1, 5 );
- textLabel1_2_2 = new QLabel( this, "textLabel1_2_2" );
+ textLabel1_2_2 = new TQLabel( this, "textLabel1_2_2" );
menuEditLayout->addWidget( textLabel1_2_2, 3, 0 );
- cbEnd = new QComboBox( FALSE, this, "cbEnd" );
+ cbEnd = new TQComboBox( FALSE, this, "cbEnd" );
menuEditLayout->addMultiCellWidget( cbEnd, 3, 3, 1, 5 );
- frame = new QFrame( this, "frame" );
- frame->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)7, 0, 0, frame->sizePolicy().hasHeightForWidth() ) );
- frame->setFrameShape( QFrame::StyledPanel );
- frame->setFrameShadow( QFrame::Raised );
+ frame = new TQFrame( this, "frame" );
+ frame->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)7, 0, 0, frame->sizePolicy().hasHeightForWidth() ) );
+ frame->setFrameShape( TQFrame::StyledPanel );
+ frame->setFrameShadow( TQFrame::Raised );
menuEditLayout->addMultiCellWidget( frame, 1, 1, 0, 5 );
languageChange();
- resize( QSize(576, 682).expandedTo(minimumSizeHint()) );
+ resize( TQSize(576, 682).expandedTo(tqminimumSizeHint()) );
clearWState( WState_Polished );
// signals and slots connections
- connect( bFont, SIGNAL( clicked() ), this, SLOT( bFontClick() ) );
- connect( urBackground, SIGNAL( urlSelected(const QString&) ), this, SLOT( urBackgroundSelected(const QString&) ) );
- connect( cbColor, SIGNAL( changed(const QColor&) ), this, SLOT( cbColorChanged(const QColor&) ) );
- connect( leTitle, SIGNAL( textChanged(const QString&) ), this, SLOT( leTitleChanged(const QString&) ) );
- connect( cbPosTitle, SIGNAL( activated(int) ), this, SLOT( cbPosTitleActivated(int) ) );
- connect( bAddText, SIGNAL( clicked() ), this, SLOT( bAddTextClick() ) );
- connect( cbStart, SIGNAL( activated(int) ), this, SLOT( cbStartActivated(int) ) );
- connect( cbEnd, SIGNAL( activated(int) ), this, SLOT( cbEndActivated(int) ) );
+ connect( bFont, TQT_SIGNAL( clicked() ), this, TQT_SLOT( bFontClick() ) );
+ connect( urBackground, TQT_SIGNAL( urlSelected(const TQString&) ), this, TQT_SLOT( urBackgroundSelected(const TQString&) ) );
+ connect( cbColor, TQT_SIGNAL( changed(const TQColor&) ), this, TQT_SLOT( cbColorChanged(const TQColor&) ) );
+ connect( leTitle, TQT_SIGNAL( textChanged(const TQString&) ), this, TQT_SLOT( leTitleChanged(const TQString&) ) );
+ connect( cbPosTitle, TQT_SIGNAL( activated(int) ), this, TQT_SLOT( cbPosTitleActivated(int) ) );
+ connect( bAddText, TQT_SIGNAL( clicked() ), this, TQT_SLOT( bAddTextClick() ) );
+ connect( cbStart, TQT_SIGNAL( activated(int) ), this, TQT_SLOT( cbStartActivated(int) ) );
+ connect( cbEnd, TQT_SIGNAL( activated(int) ), this, TQT_SLOT( cbEndActivated(int) ) );
// tab order
setTabOrder( cbStart, cbEnd );
@@ -137,7 +137,7 @@ menuEdit::menuEdit( QWidget* parent, const char* name, WFlags fl )
*/
menuEdit::~menuEdit()
{
// no need to delete child widgets, Qt does it all for us
}
/*
@@ -149,13 +149,13 @@ void menuEdit::languageChange()
setCaption( tr2i18n( "Edit Menu" ) );
textLabel2->setText( tr2i18n( "Text" ) );
textLabel1->setText( tr2i18n( "Background picture" ) );
- cbColor->setText( QString::null );
+ cbColor->setText( TQString() );
bFont->setText( tr2i18n( "Font" ) );
cbPosTitle->clear();
cbPosTitle->insertItem( tr2i18n( "Bottom" ) );
cbPosTitle->insertItem( tr2i18n( "Right" ) );
- bAddText->setText( QString::null );
- bAddText->setAccel( QKeySequence( QString::null ) );
+ bAddText->setText( TQString() );
+ bAddText->setAccel( TQKeySequence( TQString() ) );
lTitle->setText( tr2i18n( "Root Menu" ) );
textLabel1_2->setText( tr2i18n( "At start" ) );
cbStart->clear();
@@ -173,19 +173,19 @@ void menuEdit::bFontClick()
qWarning( "menuEdit::bFontClick(): Not implemented yet" );
}
-void menuEdit::urBackgroundSelected(const QString&)
+void menuEdit::urBackgroundSelected(const TQString&)
{
- qWarning( "menuEdit::urBackgroundSelected(const QString&): Not implemented yet" );
+ qWarning( "menuEdit::urBackgroundSelected(const TQString&): Not implemented yet" );
}
-void menuEdit::cbColorChanged(const QColor&)
+void menuEdit::cbColorChanged(const TQColor&)
{
- qWarning( "menuEdit::cbColorChanged(const QColor&): Not implemented yet" );
+ qWarning( "menuEdit::cbColorChanged(const TQColor&): Not implemented yet" );
}
-void menuEdit::leTitleChanged(const QString&)
+void menuEdit::leTitleChanged(const TQString&)
{
- qWarning( "menuEdit::leTitleChanged(const QString&): Not implemented yet" );
+ qWarning( "menuEdit::leTitleChanged(const TQString&): Not implemented yet" );
}
void menuEdit::cbPosTitleActivated(int)
@@ -9,40 +9,40 @@
#include "kcolorbutton.h"
/*
- * Constructs a menuEdit as a child of 'parent', with the
+ * Constructs a menuEdit as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
@@ -137,7 +137,7 @@ menuEdit::menuEdit( QWidget* parent, const char* name, WFlags fl )
menuEdit::~menuEdit()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*